@@ -26,7 +26,7 @@ class BaseProtocol:
         station = kwargs.get('code')
         sock = kwargs.get('sock')
         self.timeout = kwargs.get('timeout', 1)
-        self.raise_timeout = kwargs.get('raise_timeout', 1)
+        self.raise_timeout = kwargs.get('raise_timeout', False)
         self.raise_incompleteread = kwargs.get("raise_incomplete_read",False)        
         self.host = kwargs.get('host')
         self.port = kwargs.get('port')
@@ -77,6 +77,7 @@ class BaseProtocol:
         port = self.port
         loop = self.loop
         address = (host, port)
+        counter = 0
         while not self.status:
             try:
                 future_open_conn = asyncio.open_connection(
@@ -89,39 +90,42 @@ class BaseProtocol:
                     self.status = True
                     self.logger.info("Conexion a %s realizada" % self.station)
                 else:
-                    info = writer.get_extra_info('peername')
-                    self.logger.error(info)
+                    heartbeat = self.heart_beat(idc)
+                    self.logger.error(heartbeat)
             except asyncio.TimeoutError as te:
-                self.logger.exception("Tiempo fuera en intento de conexión %s" %te)
-                if self.raise_timeout:
-                    raise te
-                else:
-                    continue
+                self.logger.exception("Tiempo fuera en intento de conexión %s, iteracion %d" %(te, counter))
+                counter += 1
+                await asyncio.sleep(10+counter)
+                continue
             except socket.timeout as timeout:
                 self.on_blocking()
                 self.logger.error(
-                    "Error en conexión con %s:%s, error: %s" % (host, port, timeout))
+                    "Error en conexión con %s:%s, error: %s, iteración %d" % (host, port, timeout, counter))
                 #print("Error de socket a GSOF en conexión %s" % timeout)
+                counter += 1                
                 self.status = False
-                await asyncio.sleep(10)
+                await asyncio.sleep(10+counter)
                 continue
                 # await self.connect()
                 # raise timeout
             except socket.error as e:
                 self.status = False
+                counter += 1                
                 self.on_blocking()
                 if e.errno == errno.ECONNREFUSED:
                     # print("Conexión rechazada en %s" %
                     #      self.station, file=sys.stderr)
-                    self.logger.exception("Error al conectar %s, station %s" %(e, self.station))
-                    await asyncio.sleep(10)
+                    self.logger.exception("Error al conectar %s, station %s, iteración %d" %(e, self.station, counter))
+                    counter += 1
+                    await asyncio.sleep(10+counter)
                 else:
                     # print("No se puede establecer conexión, de %s" %
                     #      self.station, file=sys.stderr)
-                    self.logger.exception("Otro tipo de error al conectar %s, station %s" %(e, self.station))
-                    await asyncio.sleep(10)
+                    self.logger.exception("Otro tipo de error al conectar %s, station %s, iteración %d" %(e, self.station, counter))
+                    counter += 1                    
+                    await asyncio.sleep(10+counter)
                 continue
-            await asyncio.sleep(.2)
+            await asyncio.sleep(10+counter)
 
         return idc
 
