@@ -194,7 +194,12 @@ class Eryo(BaseProtocol):
                 return done, msg
             except asyncio.TimeoutError as te:
                 self.logger.exception("Get message records TimeoutError, %s"%te)
-                raise te                            
+                raise te
+            except asyncio.IncompleteReadError as ir:
+                print("Incomplete read on get records header, ERYO, station %s" %self.station, reader, n)
+                self.logger.exception("Station %s, Tiempo fuera al no poder leer en readbytes %s bytes, %s"%(n, self.station,ir))
+                if self.raise_incompleteread:
+                    raise ir                        
             except socket.timeout as timeout:
                 self.logger.warning(
                     "La conexión se cerró, socket timeout %s" % timeout)
