@@ -102,7 +102,12 @@ class Gsof(BaseProtocol):
                 self.msg_dict["CHECKED"] = self.checksum
             except asyncio.TimeoutError as te:
                 self.logger.exception("Get message TimeoutError, %s"%te)
-                raise te                
+                raise te
+            except asyncio.IncompleteReadError as ir:
+                print("Incomplete read on set header", reader, n)
+                self.logger.exception("Station %s, Tiempo fuera al no poder leer en readbytes %s bytes, %s"%(n, self.station,ir))
+                if self.raise_incompleteread:
+                    raise ir            
             except socket.timeout as timeout:
                 self.logger.exception(
                     "La conexión se cerró, socket timeout %s, STATION %S" % (timeout, self.station))
@@ -111,9 +116,10 @@ class Gsof(BaseProtocol):
                 self.status = False
                 raise timeout
             except Exception as ex:
+                print("Escepcion as ex: %s" %ex)
                 self.logger.exception(
                     "La conexión se cerró, error en comunicación %s" % ex)
-                self.close(idc)
+                await self.close(idc)
                 self.on_blocking()
                 info = "Error %s en estación %s. Encabezado con data %s" % (
                     ex, self.station, data)
